Temporal-package: Temporal: Parametric Time to Event Analysis

Temporal-packageR Documentation

Temporal: Parametric Time to Event Analysis

Description

Maximum likelihood estimation and inference for parametric survival models with support for right-censored data. FitParaSurv fits exponential, gamma, generalized gamma, log-normal, and Weibull distributions. CompParaSurv compares two treatment arms with respect to the mean, median, and restricted mean survival time.

Author(s)

Maintainer: Zachary McCaw zmccaw@alumni.harvard.edu (ORCID)

See Also

Useful links:


Temporal documentation built on Feb. 27, 2026, 9:06 a.m.