| Temporal-package | R Documentation |
Maximum likelihood estimation and inference for parametric survival models with support for right-censored data. FitParaSurv fits exponential, gamma, generalized gamma, log-normal, and Weibull distributions. CompParaSurv compares two treatment arms with respect to the mean, median, and restricted mean survival time.
Maintainer: Zachary McCaw zmccaw@alumni.harvard.edu (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.