Learn R Programming

Temporal (version 0.3.0.2)

Temporal-package: Temporal: Parametric Time to Event Analysis

Description

Maximum likelihood estimation and inference for parametric survival models with support for right-censored data. FitParaSurv fits exponential, gamma, generalized gamma, log-normal, and Weibull distributions. CompParaSurv compares two treatment arms with respect to the mean, median, and restricted mean survival time.

Arguments

Author

Maintainer: Zachary McCaw zmccaw@alumni.harvard.edu (ORCID)

See Also